# Generated file
NETPLAN_FEATURE_FLAGS = [
    "dhcp-use-domains",
    "ipv6-mtu",
]
